##  Thư viện đọc email sử dụng core imap lib .


### Cài đặt:
```bash
 $ pip3 install mobio-mail-client-sdk
 ```


#### Log - 0.1.0
    - tạo sdk 

#### Log - 0.1.1
    - cập nhật hàm đọc email 

#### Log - 0.1.2
    - cập nhật hàm authen access token 

#### Log - 0.1.3
    - kiểm tra init folder mailbox  

#### Log - 0.1.4
    - Bỏ lru_cache của thư viện cũ  

#### Log - 0.1.5
    - fix seen email inbox 
    